@@ -2,11 +2,14 @@ package DBIx::Class::Schema::Loader::DBI::ODBC::Microsoft_SQL_Server;
 
 use strict;
 use warnings;
-use base 'DBIx::Class::Schema::Loader::DBI::MSSQL';
+use base qw/
+    DBIx::Class::Schema::Loader::DBI::ODBC
+    DBIx::Class::Schema::Loader::DBI::MSSQL
+/;
 use Carp::Clan qw/^DBIx::Class/;
 use Class::C3;
 
-our $VERSION = '0.05001';
+our $VERSION = '0.05002';
 
 =head1 NAME
 
@@ -19,14 +22,6 @@ Proxy for L<DBIx::Class::Schema::Loader::DBI::MSSQL> when using L<DBD::ODBC>.
 
 See L<DBIx::Class::Schema::Loader::Base> for usage information.
 
-=cut
-
-sub _tables_list { 
-    my $self = shift;
-
-    return $self->next::method(undef, undef);
-}
-
 =head1 SEE ALSO
 
 L<DBIx::Class::Schema::Loader::DBI::MSSQL>,
