@@ -6,9 +6,10 @@ use base qw/
     DBIx::Class::Schema::Loader::DBI::ODBC
     DBIx::Class::Schema::Loader::DBI::SQLAnywhere
 /;
-use mro 'c3';
+use Carp::Clan qw/^DBIx::Class/;
+use Class::C3;
 
-our $VERSION = '0.07048_01';
+our $VERSION = '0.05002';
 
 =head1 NAME
 
@@ -21,32 +22,15 @@ Proxy for L<DBIx::Class::Schema::Loader::DBI::SQLAnywhere> when using L<DBD::ODB
 
 See L<DBIx::Class::Schema::Loader::Base> for usage information.
 
-=cut
-
-sub _columns_info_for {
-    my $self = shift;
-
-    my $result = $self->next::method(@_);
-
-    while (my ($col, $info) = each %$result) {
-        # The ODBC driver sets the default value to NULL even when it was not specified.
-        if (ref $info->{default_value} && ${ $info->{default_value} } eq 'null') {
-            delete $info->{default_value};
-        }
-    }
-
-    return $result;
-}
-
 =head1 SEE ALSO
 
 L<DBIx::Class::Schema::Loader::DBI::SQLAnywhere>,
 L<DBIx::Class::Schema::Loader>, L<DBIx::Class::Schema::Loader::Base>,
 L<DBIx::Class::Schema::Loader::DBI>
 
-=head1 AUTHORS
+=head1 AUTHOR
 
-See L<DBIx::Class::Schema::Loader/AUTHORS>.
+See L<DBIx::Class::Schema::Loader/AUTHOR> and L<DBIx::Class::Schema::Loader/CONTRIBUTORS>.
 
 =head1 LICENSE
 
@@ -56,4 +40,3 @@ the same terms as Perl itself.
 =cut
 
 1;
-# vim:et sw=4 sts=4 tw=0:
